==> haskell-data-bword-0.1.0.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-bword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-bword
version:              0.1.0.1
visibility:           public
id:                   data-bword-0.1.0.1-LokWhcDVyJEBaAas8WMHQT
key:                  data-bword-0.1.0.1-LokWhcDVyJEBaAas8WMHQT
license:              BSD-3-Clause
copyright:            2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-bword
synopsis:             Extra operations on binary words of fixed length
description:
    This package provides extra (vs. '\''Data.Bits'\'') operations on binary words of
    fixed length.

category:             Data
abi:                  949163c9d0b6df2bdbb5c454b3c35aa4
exposed:              True
exposed-modules:      Data.BinaryWord
import-dirs:          /usr/lib/ghc-8.10.1/site-local/data-bword-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/data-bword-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/data-bword-0.1.0.1
hs-libraries:         HSdata-bword-0.1.0.1-LokWhcDVyJEBaAas8WMHQT
depends:              base-4.14.0.0 ghc-prim-0.6.1
haddock-interfaces:   /usr/share/doc/haskell-data-bword/html/data-bword.haddock
haddock-html:         /usr/share/doc/haskell-data-bword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-bword-0.1.0.1-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-bword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-bword
version:              0.1.0.1
visibility:           public
id:                   data-bword-0.1.0.1-4wDu6Fank9iC93zANkYZRE
key:                  data-bword-0.1.0.1-4wDu6Fank9iC93zANkYZRE
license:              BSD-3-Clause
copyright:            2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-bword
synopsis:             Extra operations on binary words of fixed length
description:
    This package provides extra (vs. '\''Data.Bits'\'') operations on binary words of
    fixed length.

category:             Data
abi:                  6bbda40db240e27807410ae3c917038e
exposed:              True
exposed-modules:      Data.BinaryWord
import-dirs:          /usr/lib/ghc-8.10.2/site-local/data-bword-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/data-bword-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/data-bword-0.1.0.1
hs-libraries:         HSdata-bword-0.1.0.1-4wDu6Fank9iC93zANkYZRE
depends:              base-4.14.1.0 ghc-prim-0.6.1
haddock-interfaces:   /usr/share/doc/haskell-data-bword/html/data-bword.haddock
haddock-html:         /usr/share/doc/haskell-data-bword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
